==> aliyun-python-sdk-sas-1.1.12.tar.gz: aliyun-python-sdk-sas-1.1.12/aliyunsdksas/request/v20181203/DescribeExposedStatisticsDetailRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class DescribeExposedStatisticsDetailRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeExposedStatisticsDetail')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_StatisticsType(self):
		return self.get_query_params().get('StatisticsType')

	def set_StatisticsType(self,StatisticsType):
		self.add_query_param('StatisticsType',StatisticsType)

	def get_StatisticsTypeGatewayType(self):
		return self.get_query_params().get('StatisticsTypeGatewayType')

	def set_StatisticsTypeGatewayType(self,StatisticsTypeGatewayType):
		self.add_query_param('StatisticsTypeGatewayType',StatisticsTypeGatewayType)

	def get_CurrentPage(self):
		return self.get_query_params().get('CurrentPage')

	def set_CurrentPage(self,CurrentPage):
		self.add_query_param('CurrentPage',CurrentPage)

	def get_StatisticsTypeInstanceValue(self):
		return self.get_query_params().get('StatisticsTypeInstanceValue')

	def set_StatisticsTypeInstanceValue(self,StatisticsTypeInstanceValue):
		self.add_query_param('StatisticsTypeInstanceValue',StatisticsTypeInstanceValue)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

==> aliyun-python-sdk-sas-1.1.30.tar.gz: aliyun-python-sdk-sas-1.1.30/aliyunsdksas/request/v20181203/DescribeExposedStatisticsDetailRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class DescribeExposedStatisticsDetailRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeExposedStatisticsDetail')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_StatisticsType(self): # String
		return self.get_query_params().get('StatisticsType')

	def set_StatisticsType(self, StatisticsType):  # String
		self.add_query_param('StatisticsType', StatisticsType)
	def get_StatisticsTypeGatewayType(self): # String
		return self.get_query_params().get('StatisticsTypeGatewayType')

	def set_StatisticsTypeGatewayType(self, StatisticsTypeGatewayType):  # String
		self.add_query_param('StatisticsTypeGatewayType', StatisticsTypeGatewayType)
	def get_CurrentPage(self): # Integer
		return self.get_query_params().get('CurrentPage')

	def set_CurrentPage(self, CurrentPage):  # Integer
		self.add_query_param('CurrentPage', CurrentPage)
	def get_StatisticsTypeInstanceValue(self): # String
		return self.get_query_params().get('StatisticsTypeInstanceValue')

	def set_StatisticsTypeInstanceValue(self, StatisticsTypeInstanceValue):  # String
		self.add_query_param('StatisticsTypeInstanceValue', StatisticsTypeInstanceValue)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
